.. _install:

=====================
Install and configure
=====================

This section describes how to install and configure the
Workflow Service, code-named mistral, on the controller node.

**NOTE:** **Mistral can be used in standalone mode or it can work
with OpenStack.**

If Mistral is used with OpenStack, you must already have a working OpenStack
environment with at least the following components installed:

- Keystone with API v3 support

Note that installation and configuration vary by distribution.

.. toctree::
   :maxdepth: 2

   install-ubuntu
   install-rdo
   install-obs
